@@ -1,6 +1,6 @@
 # webdriver manager
-from je_web_runner.selenium_wrapper.webdriver_manager import get_webdriver_manager
-from je_web_runner.selenium_wrapper.webdriver_with_options import set_webdriver_options_argument
+from je_web_runner.je_web_runner.webrunner_manager import get_webdriver_manager
+from je_web_runner.je_web_runner.webdriver_with_options import set_webdriver_options_argument
 # test object
 from je_web_runner.utils.test_object.test_object_class import TestObject
 from je_web_runner.utils.test_object.test_object_class import create_test_object
@@ -13,6 +13,6 @@ from je_web_runner.selenium_utils_wrapper.keys.selenium_keys import Keys
 # utils
 from je_web_runner.utils.executor.executor import execute_action
 # webdriver wrapper
-from je_web_runner.selenium_wrapper.webdriver_wrapper import webdriver_wrapper
+from je_web_runner.je_web_runner.webdriver_wrapper import webdriver_wrapper
 # web element
-from je_web_runner.selenium_wrapper.web_element_wrapper import web_element_wrapper
+from je_web_runner.je_web_runner.web_element_wrapper import web_element_wrapper
