@@ -4,7 +4,7 @@ from je_web_runner.utils.exception.exception_tag import executor_data_error, exe
 from je_web_runner.utils.exception.exceptions import WebRunnerExecuteException
 from je_web_runner.utils.json.json_file.json_file import read_action_json
 from je_web_runner.utils.test_object.test_object_record.test_object_record_class import test_object_record
-from je_web_runner.selenium_wrapper.webdriver_manager import web_runner
+from je_web_runner.je_web_runner.webrunner_manager import web_runner
 
 event_dict = {
     # webdriver manager
@@ -113,7 +113,6 @@ def execute_action(action_list: list):
     return execute_record_string, event_response_list
 
 
-
 def execute_files(execute_files_list: list):
     """
     :param execute_files_list: list include execute files path
